CallQualityEvent class
A change in the set of active CallQualityWarnings for a call.
Constructors
-
CallQualityEvent({required Set<
CallQualityWarning> current, required Set<CallQualityWarning> previous}) -
const
Properties
-
cleared
→ Set<
CallQualityWarning> -
Warnings newly cleared by this change.
no setter
-
current
→ Set<
CallQualityWarning> -
The full set of warnings now active. Empty once quality has recovered.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasWarnings → bool
-
Whether any warning is currently active for this call.
no setter
-
previous
→ Set<
CallQualityWarning> -
The set of warnings active immediately before this change.
final
-
raised
→ Set<
CallQualityWarning> -
Warnings newly raised by this change.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited